@@ -234,7 +234,7 @@ class API:  # pylint: disable=too-many-instance-attributes
             system = system_class(
                 self._request, self._get_subscription_data, system_data["location"]
             )
-            await system.update(include_system=False, cached=False)
+            await system.update(include_system=False)
             systems[system_data["sid"]] = system
 
         return systems
